@@ -1,5 +1,6 @@
 extern crate pointprocesses;
 extern crate gnuplot;
+extern crate serde_json;
 
 use gnuplot::{Figure,Caption,Color,PointSymbol,PointSize};
 use gnuplot::AxesCommon;
@@ -30,7 +31,7 @@ fn main() {
     for i in 0..events.len() {
         let event = &events[i];
         event_times.push(event.timestamp);
-        event_intens.push(event.intensity().unwrap());
+        event_intens.push(event.intensity());
     }
 
     let mut fg = Figure::new();
